@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2005 Zope Corporation and Contributors. All Rights Reserved.
+# Copyright (c) 2005 Zope Foundation and Contributors.
 #
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
@@ -10,10 +10,7 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-"""Caching policy manager xml adapters and setup handlers.
-
-$Id: cachingpolicymgr.py 107359 2009-12-30 15:33:55Z jens $
-"""
+"""Caching policy manager xml adapters and setup handlers. """
 
 from zope.component import adapts
 from zope.component import queryMultiAdapter
