@@ -10,10 +10,7 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-"""Mailhost setup handlers.
-
-$Id: mailhost.py 110577 2010-04-07 06:33:17Z jens $
-"""
+"""Mailhost setup handlers. """
 
 from Products.MailHost.interfaces import IMailHost
 
